@@ -9,15 +9,19 @@ import numpy as np
 from .ploteos import convertido
 
 class pre_rea(object):
-    def __init__(self,obs,mod,pro):
+    def __init__(self,obs,mod,pro,anual=False):
         self.observados=obs
         self.modelos=mod
         self.proyecciones=pro
-    def rea_perform(self):
+        self.anual=anual
+    def rea_perform(self,anual=self.anual):
         obs=self.observados
         modelos=self.modelos
         proyecciones=self.proyecciones
-        iter_time=[1,2,3,4,5,6,7,8,9,10,11,12]
+        if anual==True:
+            iter_time=[1]
+        else:
+            iter_time=[1,2,3,4,5,6,7,8,9,10,11,12]
         e_fc=obs.groupby('time.month').mean('time')
         for i in iter_time:
             gg=obs.loc[obs['time.month']==i]
